import { css } from 'styled-components';

export const defaultBreakpoints = {
  giant: 1200,
  xl: 1200,
  desktop: 992,
  lg: 992,
  tablet: 768,
  md: 768,
  phone: 576,
  sm: 576,
  smaller: 575,
  xs: 575,
};

const getBreakpoints = (props) => {
  if (
    props.theme
    && props.theme.styledBootstrapGrid
    && props.theme.styledBootstrapGrid.breakpoints
  ) {
    return {
      ...defaultBreakpoints,
      ...props.theme.styledBootstrapGrid.breakpoints,
    };
  }
  return defaultBreakpoints;
};

const maxMedia = (...args) => css`
  @media (min-width: ${props => getBreakpoints(props)[label]}px) {
    ${css(...args)}
  }
`;

const minMedia = (...args) => css`
  @media (max-width: ${props => getBreakpoints(props)[label]}px) {
    ${css(...args)}
  }
`;

const media = Object.keys(defaultBreakpoints).reduce((accumulator, label) => {
  const maxQuery = maxMedia(...args);
  const minQuery = minMedia(...args);
  accumulator.max = accumulator.max || {};
  accumulator.min = accumulator.min || {};
  if (label === 'xs' || label === 'smaller') {
    accumulator[label] = maxQuery;
  } else {
    accumulator[label] = minQuery;
  }
  accumulator.max[label] = maxQuery;
  accumulator.min[label] = minQuery;
  return accumulator;
}, {});

export default media;
